@@ -3,11 +3,11 @@ package Specio::Constraint::AnyIsa;
 use strict;
 use warnings;
 
-our $VERSION = '0.41';
+our $VERSION = '0.44';
 
-use B ();
 use Role::Tiny::With;
 use Scalar::Util ();
+use Specio::Helpers qw( perlstring );
 use Specio::Library::Builtins;
 use Specio::OO;
 
@@ -24,7 +24,7 @@ with 'Specio::Constraint::Role::IsaType';
         my $self = shift;
         my $val  = shift;
 
-        return sprintf( <<'EOF', ($val) x 7, B::perlstring( $self->class ) );
+        return sprintf( <<'EOF', ($val) x 7, perlstring( $self->class ) );
 (
     (
         Scalar::Util::blessed(%s)
@@ -75,7 +75,7 @@ Specio::Constraint::AnyIsa - A class for constraints which require a class name
 
 =head1 VERSION
 
-version 0.41
+version 0.44
 
 =head1 SYNOPSIS
 
@@ -130,7 +130,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2017 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2019 by Dave Rolsky.
 
 This is free software, licensed under:
 
