@@ -3,7 +3,7 @@ package Specio::Library::Builtins;
 use strict;
 use warnings;
 
-our $VERSION = '0.41';
+our $VERSION = '0.44';
 
 use parent 'Specio::Exporter';
 
@@ -142,7 +142,7 @@ declare(
     'Int',
     parent => t('Num'),
     inline => sub {
-        return sprintf( <<'EOF', ( $_[1] ) x 6 )
+        return sprintf( <<'EOF', ( $_[1] ) x 6 );
 (
     (
         defined( %s )
@@ -300,7 +300,7 @@ declare(
     inline => sub {
         return
             sprintf(
-            <<'EOF', $_[0]->parent->inline_check( $_[1] ), ( $_[1] ) x 2 )
+            <<'EOF', $_[0]->parent->inline_check( $_[1] ), ( $_[1] ) x 2 );
 (
     ( %s )
     && length "%s"
@@ -438,7 +438,7 @@ declare(
         my $parameter = shift;
         my $val       = shift;
 
-        return sprintf( <<'EOF', $val, $parameter->inline_check($val) )
+        return sprintf( <<'EOF', $val, $parameter->inline_check($val) );
 ( !defined( %s ) || ( %s ) )
 EOF
     },
@@ -460,7 +460,7 @@ Specio::Library::Builtins - Implements type constraint objects for Perl's built-
 
 =head1 VERSION
 
-version 0.41
+version 0.44
 
 =head1 DESCRIPTION
 
@@ -588,7 +588,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2017 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2019 by Dave Rolsky.
 
 This is free software, licensed under:
 
